RequestBuilder

Struct RequestBuilder 

pub struct RequestBuilder { /* private fields */ }
Execution-free HTTP request builder.

Constructs an http::Request<Body> without performing any network I/O. The terminal method is RequestBuilder::build which returns an OxiRequest<Body>. This is distinct from oxihttp_client::RequestBuilder which owns a network connection and executes requests.

Example

use oxihttp_core::CoreRequestBuilder;

let req = CoreRequestBuilder::get("http://example.com/api")
    .expect("valid URI")
    .header("x-api-key", "secret")
    .expect("valid header")
    .build()
    .expect("valid request");

assert_eq!(req.method(), http::Method::GET);

Implementations

Source

impl RequestBuilder

pub fn new(method: Method, uri: Uri) -> Self

Create a new builder with the given method and URI.

pub fn get(uri: impl AsRef<str>) -> Result<Self, OxiHttpError>

Create a GET request builder.

pub fn post(uri: impl AsRef<str>) -> Result<Self, OxiHttpError>

Create a POST request builder.

pub fn put(uri: impl AsRef<str>) -> Result<Self, OxiHttpError>

Create a PUT request builder.

pub fn delete(uri: impl AsRef<str>) -> Result<Self, OxiHttpError>

Create a DELETE request builder.

pub fn patch(uri: impl AsRef<str>) -> Result<Self, OxiHttpError>

Create a PATCH request builder.

pub fn head(uri: impl AsRef<str>) -> Result<Self, OxiHttpError>

Create a HEAD request builder.

pub fn header( self, name: impl AsRef<str>, value: impl AsRef<str>, ) -> Result<Self, OxiHttpError>

Add a single header, replacing any existing header with the same name.

pub fn headers(self, headers: HeaderMap) -> Self

Merge a HeaderMap into the request headers, replacing duplicates.

pub fn body(self, body: impl Into<Body>) -> Self

Set a raw body (no Content-Type set automatically).

pub fn json<T: Serialize>(self, value: &T) -> Result<Self, OxiHttpError>

Set a JSON body, serialising value and setting Content-Type: application/json.

pub fn form(self, body: FormBody) -> Self

Set a URL-encoded form body, setting Content-Type: application/x-www-form-urlencoded.

Takes a crate::FormBody whose build() is infallible, so this method returns Self directly.

pub fn build(self) -> Result<OxiRequest<Body>, OxiHttpError>

Build the request.

Returns Err only when the accumulated headers, method, or URI are invalid at the http::Request layer (which should be rare given that the builder already validated each piece).