OxiHTTP Core - foundational types for the OxiHTTP Pure-Rust HTTP stack.
This crate provides the shared types used by oxihttp-client, oxihttp-server,
and the oxihttp facade crate.
Re-exports
The http crate types are re-exported for convenience.
Re-exports
pub use body::Body;pub use body::PinnedBody;pub use content_type::ContentType;pub use cookie::Cookie;pub use cookie::CookieJar;pub use cookie::SameSite;pub use error::OxiHttpError;pub use form::FormBody;pub use header_ext::HeaderMapExt;pub use header_types::Authorization;pub use header_types::CacheControl;pub use header_types::ContentLength;pub use header_types::ETag;pub use header_types::Header;pub use header_types::Host;pub use header_types::Location;pub use header_types::Referer;pub use multipart::MultipartBuilder;pub use multipart::Part as MultipartPart;pub use request_builder::RequestBuilder as CoreRequestBuilder;pub use response_ext::ResponseExt;pub use uri_ext::UriExt;pub use version::HttpVersion;
Modules
- body
- HTTP body abstraction for the OxiHTTP stack.
- content_
type - Content-Type parsing, detection, and Accept negotiation.
- cookie
- Cookie parsing and management for the OxiHTTP stack.
- error
- Error types for the OxiHTTP stack.
- form
- URL-encoded form body builder.
- header_
ext - Typed header extension traits for
HeaderMap. - header_
types - Typed header extraction framework for the OxiHTTP stack.
- multipart
- Multipart form-data body builder (RFC 7578).
- request_
builder - Execution-free HTTP request builder for constructing
http::Request<Body>values. - response_
ext - Extension trait providing ergonomic body-consuming methods on HTTP responses.
- uri_ext
- URI extension methods.
- version
- HTTP protocol version enum.
Structs
- Bytes
- A cheaply cloneable and sliceable chunk of contiguous memory.
- Bytes
Mut - A unique reference to a contiguous slice of memory.
- Header
Map - A specialized multimap for header names and values.
- Header
Name - Represents an HTTP header field name
- Header
Value - Represents an HTTP header field value.
- Method
- The Request Method (VERB)
- Request
- Represents an HTTP request.
- Response
- Represents an HTTP response
- Status
Code - An HTTP status code (
status-codein RFC 9110 et al.). - Uri
- The URI component of a request.
- Version
- Represents a version of the HTTP spec.
Type Aliases
- OxiRequest
- Type alias for an HTTP request carrying an
Body. - OxiResponse
- Type alias for an HTTP response carrying an
Body. - Result
- Type alias for
Result<T, OxiHttpError>.