Execution-free HTTP request builder for constructing http::Request<Body> values.
Unlike the client’s request builder, this builder has no network I/O — the terminal method
is .build() which returns an OxiRequest<Body>. Useful for tests, server-side request
forging, and as a reusable base for building requests without a live connection.
Structs
- Request
Builder - Execution-free HTTP request builder.